stalker.ext.auth.login_required — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

# stalker.ext.auth.login_required

static `auth.` `login_required`(view, error_message=None)

  a decorator that implements login functionality to any function or method

  Parameters: | view – a function returning True or False, thus verifying the entered user name and password error_message – the message to be shown in case a LoginError is raised, a default message will be shown when skipped
  Returns: | the decorated function

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »